"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var service_1 = require("./service");
var models_1 = require("../models");
var common_1 = require("../common");
var Issues;
(function (Issues) {
    function getAll(state, scope, labels, milestoneTitle, orderBy, sort, search, milestoneIds, authoredBy, assignedTo) {
        if (state === void 0) { state = undefined; }
        if (scope === void 0) { scope = models_1.Scope.ALL; }
        if (labels === void 0) { labels = undefined; }
        if (milestoneTitle === void 0) { milestoneTitle = undefined; }
        if (orderBy === void 0) { orderBy = models_1.Orderby.CREATED_AT; }
        if (sort === void 0) { sort = models_1.SortOrder.DESCENDING; }
        if (search === void 0) { search = undefined; }
        if (milestoneIds === void 0) { milestoneIds = undefined; }
        if (authoredBy === void 0) { authoredBy = undefined; }
        if (assignedTo === void 0) { assignedTo = undefined; }
        var params = [];
        params.push(common_1.REST.QueryParam.createQuery('state', state));
        params.push(common_1.REST.QueryParam.createQuery('scope', scope));
        params.push(common_1.REST.QueryParam.createQuery('labels', labels ? labels.join(',') : undefined));
        params.push(common_1.REST.QueryParam.createQuery('milestone', milestoneTitle));
        params.push(common_1.REST.QueryParam.createQuery('order_by', orderBy));
        params.push(common_1.REST.QueryParam.createQuery('sort', sort));
        params.push(common_1.REST.QueryParam.createQuery('search', search));
        params.push.apply(params, (milestoneIds || []).map(function (iid) { return common_1.REST.QueryParam.createQuery('iids[]', iid); }));
        params.push(common_1.REST.QueryParam.createQuery('author_id', authoredBy));
        params.push(common_1.REST.QueryParam.createQuery('assignee_id', assignedTo));
        return new Promise(function (resolve, reject) {
            service_1.service.get("/issues?" + common_1.REST.QueryParam.join(params))
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    Issues.getAll = getAll;
    function getAllOfProject(projectId, state, scope, labels, milestoneTitle, sort, search, milestoneIds, authoredBy, assignedTo) {
        if (state === void 0) { state = undefined; }
        if (scope === void 0) { scope = models_1.Scope.ALL; }
        if (labels === void 0) { labels = undefined; }
        if (milestoneTitle === void 0) { milestoneTitle = undefined; }
        if (sort === void 0) { sort = models_1.SortOrder.DESCENDING; }
        if (search === void 0) { search = undefined; }
        if (milestoneIds === void 0) { milestoneIds = undefined; }
        if (authoredBy === void 0) { authoredBy = undefined; }
        if (assignedTo === void 0) { assignedTo = undefined; }
        var params = [];
        params.push(common_1.REST.QueryParam.createQuery('state', state));
        params.push(common_1.REST.QueryParam.createQuery('scope', scope));
        params.push(common_1.REST.QueryParam.createQuery('labels', labels ? labels.join(',') : undefined));
        params.push(common_1.REST.QueryParam.createQuery('milestone', milestoneTitle));
        params.push(common_1.REST.QueryParam.createQuery('sort', sort));
        params.push(common_1.REST.QueryParam.createQuery('search', search));
        params.push.apply(params, (milestoneIds || []).map(function (iid) { return common_1.REST.QueryParam.createQuery('iids[]', iid); }));
        params.push(common_1.REST.QueryParam.createQuery('author_id', authoredBy));
        params.push(common_1.REST.QueryParam.createQuery('assignee_id', assignedTo));
        return new Promise(function (resolve, reject) {
            service_1.service.get("/projects/" + projectId + "/issues?" + common_1.REST.QueryParam.join(params))
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    Issues.getAllOfProject = getAllOfProject;
    function getOneOfProject(projectId, issueId) {
        return new Promise(function (resolve, reject) {
            service_1.service.get("/projects/" + projectId + "/issues/" + issueId)
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    Issues.getOneOfProject = getOneOfProject;
    function create(projectId, title, description, confidential, assigneeIds, milestoneId, labels, dueDate) {
        if (confidential === void 0) { confidential = false; }
        var params = [];
        params.push(common_1.REST.QueryParam.createQuery('title', title));
        params.push(common_1.REST.QueryParam.createQuery('description', description));
        params.push(common_1.REST.QueryParam.createQuery('confidential', confidential.toString()));
        params.push(common_1.REST.QueryParam.createQuery('milestone_id', milestoneId));
        params.push(common_1.REST.QueryParam.createQuery('labels', labels && labels.join(',')));
        params.push(common_1.REST.QueryParam.createQuery('due_date', dueDate && dueDate.toDateString()));
        return new Promise(function (resolve, reject) {
            service_1.service.post("/projects/" + projectId + "/issues?" + common_1.REST.QueryParam.join(params))
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    Issues.create = create;
})(Issues = exports.Issues || (exports.Issues = {}));
//# sourceMappingURL=issues.js.map