"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var service_1 = require("./service");
var common_1 = require("../common");
var ProjectMilestones;
(function (ProjectMilestones) {
    function getAll(projectId, state, search, milestoneIds) {
        if (state === void 0) { state = undefined; }
        if (search === void 0) { search = undefined; }
        if (milestoneIds === void 0) { milestoneIds = undefined; }
        var params = [];
        params.push(common_1.REST.QueryParam.createQuery('state', state));
        params.push(common_1.REST.QueryParam.createQuery('search', search));
        params.push.apply(params, (milestoneIds || []).map(function (iid) { return common_1.REST.QueryParam.createQuery('iids[]', iid); }));
        return new Promise(function (resolve, reject) {
            service_1.service.get("/projects/" + projectId + "/milestones?" + common_1.REST.QueryParam.join(params))
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    ProjectMilestones.getAll = getAll;
    function getOne(projectId, milestoneId) {
        return new Promise(function (resolve, reject) {
            service_1.service.get("/projects/" + projectId + "/milestones/" + milestoneId)
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    ProjectMilestones.getOne = getOne;
    function create(projectId, title, description, dueDate, startDate) {
        var params = [];
        params.push(common_1.REST.QueryParam.createQuery('title', title));
        params.push(common_1.REST.QueryParam.createQuery('description', description));
        params.push(common_1.REST.QueryParam.createQuery('due_date', dueDate && dueDate.toDateString()));
        params.push(common_1.REST.QueryParam.createQuery('start_date', startDate && startDate.toDateString()));
        return new Promise(function (resolve, reject) {
            service_1.service.post("/projects/" + projectId + "/milestones?" + params.join('&'))
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    ProjectMilestones.create = create;
    function edit(projectId, milestoneId, title, description, dueDate, startDate, stateEvent) {
        var params = [];
        params.push(common_1.REST.QueryParam.createQuery('title', title));
        params.push(common_1.REST.QueryParam.createQuery('description', description));
        params.push(common_1.REST.QueryParam.createQuery('due_date', dueDate && dueDate.toDateString()));
        params.push(common_1.REST.QueryParam.createQuery('start_date', startDate && startDate.toDateString()));
        params.push(common_1.REST.QueryParam.createQuery('state_event', stateEvent));
        return new Promise(function (resolve, reject) {
            service_1.service.post("/projects/" + projectId + "/milestones/" + milestoneId + "?" + params.join('&'))
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    ProjectMilestones.edit = edit;
    function getIssues(projectId, milestoneId) {
        return new Promise(function (resolve, reject) {
            service_1.service.get("/projects/" + projectId + "/milestones/" + milestoneId + "/issues")
                .then(function (result) { return resolve(result.body); })
                .catch(function (error) { return reject(error); });
        });
    }
    ProjectMilestones.getIssues = getIssues;
})(ProjectMilestones = exports.ProjectMilestones || (exports.ProjectMilestones = {}));
//# sourceMappingURL=project-milestones.js.map